

dirpath = "D:/BBB/ProgOutput/Lucas"



plot.ecdfs <- function(dh, mh, titletxt, num) {
	maxh = max(dh, mh)
	minh = min(dh, mh)
	cdf = seq(from=0, to=1, length.out=101)
	qdh = quantile(dh, cdf)
	qmh = quantile(mh, cdf)
	matplot(qdh, cdf, type='l', xlim=c(minh, maxh), xlab=paste0("length of interval ", num), col="black")
	lines(qmh, cdf, col="red")
	text(x=(maxh+minh)*.6, y=0.3, "True empirical cdf", col="black")
	text(x=(maxh+minh)*.6, y=0.2, "Approx empirical cdf", col="red")
	title(titletxt)
}



write.median.ctimes <- function(test, dhgts, mhgts, textfpath) {
  cat(test, "\n                median                        mean\ncoalescence true       estimate          true       estimate\n", file=textfpath, append=TRUE)
  for (i in 1:ncol(dhgts)) {
    meddh = median(dhgts[,i])
    medmh = median(mhgts[,i])
    meandh = mean(dhgts[,i])
    meanmh = mean(mhgts[,i])
    logratio = log(meddh/medmh)
    txt = ""
    if (abs(logratio) > log(1.4)) {
      txt = "*"
    }
    if (abs(logratio) > log(2)) {
      txt = "**"
    }
    if (abs(logratio) > log(4)) {
      txt = "***"
    }
    cat(i, "     ", meddh, "  ", medmh, "     ", meandh, "  ", meanmh, txt, "\n", file=textfpath, append=TRUE)
  }
  cat("\n", file=textfpath, append=TRUE)
}



do.tests.on.list <- function(tests, out.fname) {
  pdf(file = paste0(dirpath, "/", out.fname, ".pdf"))
  textfpath = paste0(dirpath, "/", out.fname, ".txt")
  cat("\n", file = textfpath)
  for (test in tests) {
    testdpath = paste0(dirpath, "/", test)
    direct = read.table(file=paste0(testdpath, "/", "directCollection.txt"), header = TRUE)
    mcmc = read.table(file=paste0(testdpath, "/", "MCMC.txt"), header = TRUE)
    
    ncol = ncol(direct)
    stopifnot(ncol == ncol(mcmc))
    stopifnot((ncol - 2) %% 5 == 0)
    ss = 1 + (ncol - 2) / 5
    stopifnot(ss %% 2 == 0)
    nlins =  ss / 2    
    
    coalidxs = nlins:(2*nlins-2)
    dhgts = as.matrix(direct[, paste0("hgt", coalidxs)])
    mhgts = as.matrix(mcmc[, paste0("hgt", coalidxs)])
    for (i in 1:nrow(dhgts)) {
      dhgts[i,] = sort(dhgts[i,])
      mhgts[i,] = sort(mhgts[i,])
    }
    write.median.ctimes(test, dhgts, mhgts, textfpath)
    for (i in 1:(nlins-1)) {
      if (i==1) {
        prevd = prevm = 0
      } else {
        prevd = dhgts[,i-1]
        prevm = mhgts[,i-1]
        
      }
      plot.ecdfs(dhgts[,i] - prevd, mhgts[,i] - prevm, paste(test, "interval", i), i)
    }
  }
  dev.off()
}




do.tests.on.list(c("Testspp5lins4+4+4+4+4m05", "Testspp5lins4+4+4+4+4m5",
                 "Testspp5lins4+4+4+4+4m50", "Testspp5lins4+4+4+4+4m500"), "test5x4")


do.tests.on.list(c("Testspp5lins1+1+1+1+1m05", "Testspp5lins1+1+1+1+1m5",
                    "Testspp5lins1+1+1+1+1m50", "Testspp5lins1+1+1+1+1m500"), "test5x1")

do.tests.on.list(c("Testspp3lins3+2+0m05", "Testspp3lins3+2+0m5",
                   "Testspp3lins3+2+0m50", "Testspp3lins3+2+0m500"), "test3-320")


tests2lin = c("Testspp2lins2m05", "Testspp2lins2m5", "Testspp2lins2m50", "Testspp2lins2m500",
              "Testspp3lins2m05", "Testspp3lins2m5", "Testspp3lins2m50", "Testspp3lins2m500",
              "Testspp6lins2m05", "Testspp6lins2m5", "Testspp6lins2m50", "Testspp6lins2m500")
do.tests.on.list(tests2lin, "test2lins")

do.tests.on.list(c("Testspp20lins20x1m005", "Testspp20lins20x1m05"), "test20x1")

